==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkUnstructuredGridVolumeMapper.java <==
// java wrapper for vtkUnstructuredGridVolumeMapper object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGridVolumeMapper extends vtkAbstractVolumeMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkUnstructuredGridBase id0);
  public void SetInputData(vtkUnstructuredGridBase id0)
    { SetInputData_2(id0); }

  private native void SetInputData_3(vtkDataSet id0);
  public void SetInputData(vtkDataSet id0)
    { SetInputData_3(id0); }

  private native long GetInput_4();
  public vtkUnstructuredGridBase GetInput() {
    long temp = GetInput_4();

    if (temp == 0) return null;
    return (vtkUnstructuredGridBase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBlendMode_5(int id0);
  public void SetBlendMode(int id0)
    { SetBlendMode_5(id0); }

  private native void SetBlendModeToComposite_6();
  public void SetBlendModeToComposite()
    { SetBlendModeToComposite_6(); }

  private native void SetBlendModeToMaximumIntensity_7();
  public void SetBlendModeToMaximumIntensity()
    { SetBlendModeToMaximumIntensity_7(); }

  private native int GetBlendMode_8();
  public int GetBlendMode()
    { return GetBlendMode_8(); }

  private native void Render_9(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_9(id0,id1); }

  private native void ReleaseGraphicsResources_10(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_10(id0); }

  public vtkUnstructuredGridVolumeMapper() { super(); }

  public vtkUnstructuredGridVolumeMapper(long id) { super(id); }

}

==> vtk-8.2.0-21-armv7h.pkg.tar.xz: vtk/vtkUnstructuredGridVolumeMapper.java <==
// java wrapper for vtkUnstructuredGridVolumeMapper object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGridVolumeMapper extends vtkAbstractVolumeMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkUnstructuredGridBase id0);
  public void SetInputData(vtkUnstructuredGridBase id0)
    { SetInputData_2(id0); }

  private native void SetInputData_3(vtkDataSet id0);
  public void SetInputData(vtkDataSet id0)
    { SetInputData_3(id0); }

  private native long GetInput_4();
  public vtkUnstructuredGridBase GetInput() {
    long temp = GetInput_4();

    if (temp == 0) return null;
    return (vtkUnstructuredGridBase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBlendMode_5(int id0);
  public void SetBlendMode(int id0)
    { SetBlendMode_5(id0); }

  private native void SetBlendModeToComposite_6();
  public void SetBlendModeToComposite()
    { SetBlendModeToComposite_6(); }

  private native void SetBlendModeToMaximumIntensity_7();
  public void SetBlendModeToMaximumIntensity()
    { SetBlendModeToMaximumIntensity_7(); }

  private native int GetBlendMode_8();
  public int GetBlendMode()
    { return GetBlendMode_8(); }

  private native void Render_9(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_9(id0,id1); }

  private native void ReleaseGraphicsResources_10(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_10(id0); }

  public vtkUnstructuredGridVolumeMapper() { super(); }

  public vtkUnstructuredGridVolumeMapper(long id) { super(id); }

}
